@@ -11,16 +11,11 @@
 #include <string.h>
 #include <math.h>
 
-#ifdef WIN32
+#ifdef _WIN32
 #include <windows.h>
 #endif
 
-#include <GL/glut.h>
-
-#ifdef XMESA
-#include "GL/xmesa.h"
-static int fullscreen = 1;
-#endif
+#include "glut_wrap.h"
 
 static int WIDTH = 640;
 static int HEIGHT = 480;
@@ -226,12 +221,6 @@ key(unsigned char k, int x, int y)
 	 poutline = 1;
       }
       break;
-#ifdef XMESA
-   case ' ':
-      XMesaSetFXmode(fullscreen ? XMESA_FX_FULLSCREEN : XMESA_FX_WINDOW);
-      fullscreen = (!fullscreen);
-      break;
-#endif
    }
 }
 
@@ -560,7 +549,7 @@ drawobj(void)
 static void
 dojoy(void)
 {
-#ifdef WIN32
+#ifdef _WIN32
    static UINT max[2] = { 0, 0 };
    static UINT min[2] = { 0xffffffff, 0xffffffff }, center[2];
    MMRESULT res;
@@ -739,6 +728,7 @@ draw(void)
          GLfloat seconds = (t - T0) / 1000.0;
          GLfloat fps = Frames / seconds;
          sprintf(frbuf, "Frame rate: %f", fps);
+         printf("%s\n", frbuf);
          T0 = t;
          Frames = 0;
       }
@@ -880,9 +870,6 @@ main(int ac, char **av)
    glFogfv(GL_FOG_COLOR, fogcolor);
 
    glFogf(GL_FOG_DENSITY, 0.01);
-#ifdef FX
-   glHint(GL_FOG_HINT, GL_NICEST);
-#endif
 
    calcposobs();
 
