@@ -3,12 +3,12 @@
 #include <string.h>
 #include <stdlib.h>
 
-#ifndef WIN32
+#ifndef _WIN32
 #include <unistd.h>
 #include <signal.h>
 #endif
 
-#include <GL/glew.h>
+#include <glad/glad.h>
 #include "glut_wrap.h"
 
 #include "readtex.c"
@@ -71,7 +71,7 @@ static void args(int argc, char *argv[])
 static void Init( void )
 {
    GLuint Texture;
-   GLint errno;
+   GLint errnum;
    GLuint prognum;
    char buf[50000];
    GLuint sz;
@@ -89,7 +89,7 @@ static void Init( void )
    }
    fprintf(stderr, "%.*s\n", sz, buf);
 
-   if (!GLEW_ARB_fragment_program) {
+   if (!GLAD_GL_ARB_fragment_program) {
       printf("Error: GL_ARB_fragment_program not supported!\n");
       exit(1);
    }
@@ -101,9 +101,9 @@ static void Init( void )
    glProgramStringARB(GL_FRAGMENT_PROGRAM_ARB, GL_PROGRAM_FORMAT_ASCII_ARB,
                       sz, (const GLubyte *)buf);
 
-   errno = glGetError();
-   printf("glGetError = 0x%x\n", errno);
-   if (errno != GL_NO_ERROR) {
+   errnum = glGetError();
+   printf("glGetError = 0x%x\n", errnum);
+   if (errnum != GL_NO_ERROR) {
       GLint errorpos;
 
       glGetIntegerv(GL_PROGRAM_ERROR_POSITION_ARB, &errorpos);
@@ -252,7 +252,7 @@ int main(int argc, char **argv)
    glutInitDisplayMode(GLUT_RGB | GLUT_SINGLE | GLUT_DEPTH);
    args(argc, argv);
    glutCreateWindow(filename);
-   glewInit();
+   gladLoadGL();
    glutReshapeFunc(Reshape);
    glutKeyboardFunc(Key);
    glutDisplayFunc(Draw);
